@@ -5,6 +5,7 @@ from .base_manager import BaseManager
 from .pubsub_manager import PubSubManager
 from .kombu_manager import KombuManager
 from .redis_manager import RedisManager
+from .kafka_manager import KafkaManager
 from .zmq_manager import ZmqManager
 from .server import Server
 from .namespace import Namespace, ClientNamespace
@@ -16,6 +17,7 @@ if sys.version_info >= (3, 5):  # pragma: no cover
     from .asyncio_manager import AsyncManager
     from .asyncio_namespace import AsyncNamespace, AsyncClientNamespace
     from .asyncio_redis_manager import AsyncRedisManager
+    from .asyncio_aiopika_manager import AsyncAioPikaManager
     from .asgi import ASGIApp
 else:  # pragma: no cover
     AsyncClient = None
@@ -23,13 +25,14 @@ else:  # pragma: no cover
     AsyncManager = None
     AsyncNamespace = None
     AsyncRedisManager = None
+    AsyncAioPikaManager = None
 
-__version__ = '4.2.1'
+__version__ = '4.4.0'
 
 __all__ = ['__version__', 'Client', 'Server', 'BaseManager', 'PubSubManager',
-           'KombuManager', 'RedisManager', 'ZmqManager', 'Namespace',
-           'ClientNamespace', 'WSGIApp', 'Middleware']
+           'KombuManager', 'RedisManager', 'ZmqManager', 'KafkaManager',
+           'Namespace', 'ClientNamespace', 'WSGIApp', 'Middleware']
 if AsyncServer is not None:  # pragma: no cover
     __all__ += ['AsyncClient', 'AsyncServer', 'AsyncNamespace',
                 'AsyncClientNamespace', 'AsyncManager', 'AsyncRedisManager',
-                'ASGIApp', 'get_tornado_handler']
+                'ASGIApp', 'get_tornado_handler', 'AsyncAioPikaManager']
